@@ -5,6 +5,7 @@ Abstract base class for jobs
 import abc
 import asyncio
 import collections
+import functools
 import os
 import pickle
 import re
@@ -12,7 +13,6 @@ import re
 import unidecode
 
 from .. import constants, utils
-from ..utils import cached_property
 
 import logging  # isort:skip
 _log = logging.getLogger(__name__)
@@ -70,7 +70,7 @@ class JobBase(abc.ABC):
             utils.fs.mkdir(self._home_directory)
         return self._home_directory
 
-    @cached_property
+    @functools.cached_property
     def cache_directory(self):
         """
         Path to existing directory that stores :attr:`cache_file`
@@ -114,6 +114,9 @@ class JobBase(abc.ABC):
 
     @precondition.setter
     def precondition(self, function):
+        if self.is_started:
+            raise RuntimeError('Cannot set precondition after job has been started')
+
         if not callable(function):
             raise TypeError(f'Not callable: {function!r}')
         self._precondition = function
@@ -132,6 +135,8 @@ class JobBase(abc.ABC):
 
     @prejobs.setter
     def prejobs(self, prejobs):
+        if self.is_started:
+            raise RuntimeError('Cannot set prejobs after job has been started')
         self._prejobs = tuple(prejobs)
 
     def presignal(self, job, signal):
@@ -148,6 +153,9 @@ class JobBase(abc.ABC):
 
         See also :attr:`is_enabled`.
         """
+        if self.is_started:
+            raise RuntimeError('Cannot set presignal after job has been started')
+
         # Indicate we are waiting for signal
         self.presignals[job][signal] = False
 
@@ -160,7 +168,7 @@ class JobBase(abc.ABC):
 
         job.signal.register(signal, presignal_handler)
 
-    @cached_property
+    @functools.cached_property
     def presignals(self):
         return collections.defaultdict(lambda: {})
 
@@ -251,7 +259,6 @@ class JobBase(abc.ABC):
         self._ignore_cache = bool(ignore_cache)
         self._hidden = bool(hidden)
         self._autostart = bool(autostart)
-        self.precondition = precondition if precondition is not None else (lambda: True)
         self._is_started = False
         self._is_executed = False
         self._exception = None
@@ -261,6 +268,7 @@ class JobBase(abc.ABC):
         self._info = ''
         self._tasks = []
         self._finished_event = asyncio.Event()
+        self.precondition = precondition if precondition is not None else (lambda: True)
         self.prejobs = prejobs
 
         self._signal = utils.signal.Signal(
@@ -626,7 +634,7 @@ class JobBase(abc.ABC):
 
     _max_filename_len = 255
 
-    @cached_property
+    @functools.cached_property
     def cache_file(self):
         """
         File path in :attr:`cache_directory` to store cached :attr:`output` in
@@ -653,7 +661,7 @@ class JobBase(abc.ABC):
             filename = utils.fs.sanitize_filename(filename)
         return os.path.join(self.cache_directory, filename)
 
-    @cached_property
+    @functools.cached_property
     def cache_id(self):
         """
         Unique object based on the job's input data
