@@ -462,12 +462,17 @@ class TextFieldJob(JobBase):
                 self.fetch_text(coro=text(), finish_on_success=autofinish),
             )
 
-        elif text is not None:
-            if callable(text):
+        elif callable(text):
+            try:
                 self.text = text()
+            except BaseException as e:
+                self.exception(e)
             else:
-                self.text = text
+                if autofinish:
+                    self.send(self.text)
 
+        elif text is not None:
+            self.text = text
             if autofinish:
                 self.send(self.text)
 
