@@ -2,6 +2,7 @@
 Create screenshots from video file(s)
 """
 
+import collections
 import os
 import queue
 
@@ -40,8 +41,7 @@ class ScreenshotsJob(JobBase):
         :param str content_path: Path to file or directory or sequence of paths
         :param exclude_files: Sequence of glob patterns (:class:`str`) and
             :class:`re.Pattern` objects (return value from :func:`re.compile`)
-            that are matched against the relative path within the generated
-            torrent
+            that are matched against the relative path beneath `content_path`
 
             Glob patterns are matched case-insensitively.
 
@@ -67,6 +67,7 @@ class ScreenshotsJob(JobBase):
         self._count = count
         self._from_all_videos = from_all_videos
         self._screenshots_process = None
+        self._screenshots_by_file = collections.defaultdict(lambda: [])
         self.signal.add('screenshots_total', record=True)
 
     def execute(self):
@@ -107,6 +108,7 @@ class ScreenshotsJob(JobBase):
 
             if 'screenshot_path' in info:
                 self._screenshots_created += 1
+                self._screenshots_by_file[info['video_path']].append(info['screenshot_path'])
                 self.send(info['screenshot_path'])
 
     def _handle_error(self, error):
@@ -249,6 +251,17 @@ class ScreenshotsJob(JobBase):
         """Total number of screenshots made so far"""
         return self._screenshots_created
 
+    @property
+    def screenshots_by_file(self):
+        """
+        Map source video file paths to sequence of generated screenshot file
+        paths so far
+        """
+        return {
+            video_path: tuple(screenshot_paths)
+            for video_path, screenshot_paths in self._screenshots_by_file.items()
+        }
+
 
 def _screenshots_process(output_queue, input_queue,
                          *, content_path, exclude_files, timestamps, count, from_all_videos,
@@ -293,7 +306,7 @@ def _get_video_files(output_queue, *, content_path, exclude_files):
     # Make list of appropriate video file(s) from `content_path`
     try:
         filtered_files = torrent.filter_files(content_path, exclude=exclude_files)
-        return video.filter_main_videos(tuple(filtered_files))
+        return video.filter_main_videos(filtered_files)
     except errors.ContentError as e:
         output_queue.put((daemon.MsgType.error, str(e)))
         return []
@@ -341,7 +354,10 @@ def _make_screenshot(output_queue, *, video_file, timestamp, output_dir, overwri
     except errors.ScreenshotError as e:
         output_queue.put((daemon.MsgType.error, str(e)))
     else:
-        output_queue.put((daemon.MsgType.info, {'screenshot_path': actual_screenshot_file}))
+        output_queue.put((daemon.MsgType.info, {
+            'video_path': video_file,
+            'screenshot_path': actual_screenshot_file,
+        }))
 
 
 def _map_timestamps(*, video_files, timestamps, count):
@@ -361,6 +377,8 @@ def _validate_timestamps(*, video_file, timestamps, count):
 
     # Stay clear of the last 10 seconds
     duration = video.duration(video_file) - 10
+    if duration < 60:
+        return []
 
     timestamps_pretty = set()
     for ts in timestamps:
