@@ -11,7 +11,7 @@ subclasses have two main purposes:
 """
 
 from .. import utils
-from . import dummy, nbl
+from . import bhd, dummy, mtv, nbl, ptp
 from .base import TrackerBase, TrackerConfigBase, TrackerJobsBase
 
 
