@@ -4,10 +4,12 @@ Abstract base class for tracker jobs
 
 import abc
 import builtins
+import collections
+import functools
 import os
+import pathlib
 
 from ... import errors, jobs, utils
-from ...utils import cached_property
 
 import logging  # isort:skip
 _log = logging.getLogger(__name__)
@@ -149,7 +151,7 @@ class TrackerJobsBase(abc.ABC):
         be called
         """
 
-    @cached_property
+    @functools.cached_property
     def jobs_after_upload(self):
         """
         Sequence of jobs that are started after :meth:`~.TrackerBase.upload`
@@ -289,17 +291,17 @@ class TrackerJobsBase(abc.ABC):
         """
         self.signal.emit('exception', exception)
 
-    @cached_property
+    @functools.cached_property
     def imdb(self):
         """:class:`~.webdbs.imdb.ImdbApi` instance"""
         return utils.webdbs.webdb('imdb')
 
-    @cached_property
+    @functools.cached_property
     def tmdb(self):
         """:class:`~.webdbs.tmdb.TmdbApi` instance"""
         return utils.webdbs.webdb('tmdb')
 
-    @cached_property
+    @functools.cached_property
     def tvmaze(self):
         """:class:`~.webdbs.tvmaze.TvmazeApi` instance"""
         return utils.webdbs.webdb('tvmaze')
@@ -322,7 +324,7 @@ class TrackerJobsBase(abc.ABC):
         else:
             return f'{prefix}{name}'
 
-    @cached_property
+    @functools.cached_property
     def create_torrent_job(self):
         """:class:`~.jobs.torrent.CreateTorrentJob` instance"""
         return jobs.torrent.CreateTorrentJob(
@@ -340,7 +342,7 @@ class TrackerJobsBase(abc.ABC):
     torrent_piece_size_max = 16 * 2**20  # 16 MiB
     """Maximum torrent piece size for this tracker"""
 
-    @cached_property
+    @functools.cached_property
     def add_torrent_job(self):
         """:class:`~.jobs.torrent.AddTorrentJob` instance"""
         if self.bittorrent_client and self.create_torrent_job:
@@ -361,7 +363,7 @@ class TrackerJobsBase(abc.ABC):
     def finalize_add_torrent_job(self, _):
         self.add_torrent_job.finalize()
 
-    @cached_property
+    @functools.cached_property
     def copy_torrent_job(self):
         """:class:`~.jobs.torrent.CopyTorrentJob` instance"""
         if self.torrent_destination and self.create_torrent_job:
@@ -380,7 +382,7 @@ class TrackerJobsBase(abc.ABC):
     def finalize_copy_torrent_job(self, _):
         self.copy_torrent_job.finalize()
 
-    @cached_property
+    @functools.cached_property
     def release_name(self):
         """
         :class:`~.release.ReleaseName` instance with
@@ -398,7 +400,7 @@ class TrackerJobsBase(abc.ABC):
     release_name_translation = {}
     """See ``translate`` argument of :attr:`~.utils.release.ReleaseName`"""
 
-    @cached_property
+    @functools.cached_property
     def release_name_job(self):
         """
         :class:`~.jobs.dialog.TextFieldJob` instance with text set to
@@ -433,7 +435,7 @@ class TrackerJobsBase(abc.ABC):
         )
         _log.debug('Updated release name: %s', self.release_name)
 
-    @cached_property
+    @functools.cached_property
     def imdb_job(self):
         """:class:`~.jobs.webdb.WebDbSearchJob` instance"""
         return jobs.webdb.WebDbSearchJob(
@@ -459,7 +461,7 @@ class TrackerJobsBase(abc.ABC):
         """IMDb ID if :attr:`imdb_job` is finished or `None`"""
         return self._get_webdb_id_from_job(self.imdb_job)
 
-    @cached_property
+    @functools.cached_property
     def tmdb_job(self):
         """:class:`~.jobs.webdb.WebDbSearchJob` instance"""
         return jobs.webdb.WebDbSearchJob(
@@ -484,7 +486,7 @@ class TrackerJobsBase(abc.ABC):
         """TMDb ID if :attr:`tmdb_job` is finished or `None`"""
         return self._get_webdb_id_from_job(self.tmdb_job)
 
-    @cached_property
+    @functools.cached_property
     def tvmaze_job(self):
         """:class:`~.jobs.webdb.WebDbSearchJob` instance"""
         return jobs.webdb.WebDbSearchJob(
@@ -537,7 +539,7 @@ class TrackerJobsBase(abc.ABC):
 
         await self.update_release_name_from(webdb, webdb_id)
 
-    @cached_property
+    @functools.cached_property
     def screenshots_job(self):
         """
         :class:`~.jobs.screenshots.ScreenshotsJob` instance
@@ -559,8 +561,8 @@ class TrackerJobsBase(abc.ABC):
         """
         How many screenshots to make
 
-        The default implementation uses :attr:`options`\\ ``[screenshots]`` with
-        `None` as the default value.
+        The default implementation uses :attr:`options`\\ ``["screenshots"]``
+        with `None` as the default value.
         """
         return self.options.get('screenshots')
 
@@ -595,7 +597,7 @@ class TrackerJobsBase(abc.ABC):
     ... }
     """
 
-    @cached_property
+    @functools.cached_property
     def upload_screenshots_job(self):
         """:class:`~.jobs.imghost.ImageHostJob` instance"""
         if self.image_host and self.screenshots_job:
@@ -617,7 +619,7 @@ class TrackerJobsBase(abc.ABC):
     def finalize_upload_screenshots_job(self, _):
         self.upload_screenshots_job.finalize()
 
-    @cached_property
+    @functools.cached_property
     def poster_job(self):
         """
         :class:`~.jobs.poster.PosterJob` instance
@@ -648,7 +650,7 @@ class TrackerJobsBase(abc.ABC):
     poster_max_height = 500
     """Maximum poster image height"""
 
-    @cached_property
+    @functools.cached_property
     def _poster_webdb(self):
         """:class:`~.webdbs.base.WebDbApiBase` instance for finding poster image"""
         if (
@@ -679,12 +681,13 @@ class TrackerJobsBase(abc.ABC):
             else:
                 raise RuntimeError('You must add a WebDbSearchJob instance to jobs_before_upload')
 
-    @cached_property
+    @functools.cached_property
     def mediainfo_job(self):
         """:class:`~.jobs.mediainfo.MediainfoJob` instance"""
         return jobs.mediainfo.MediainfoJob(
             content_path=self.content_path,
             from_all_videos=self.mediainfo_from_all_videos,
+            exclude_files=self.exclude_files,
             precondition=self.make_precondition('mediainfo_job'),
             **self.common_job_args(),
         )
@@ -701,7 +704,94 @@ class TrackerJobsBase(abc.ABC):
         """
         return False
 
-    @cached_property
+    @property
+    def mediainfos_and_screenshots(self):
+        """
+        Map video file paths to mediainfo and screenshot URLs
+
+        This property uses the results of :attr:`mediainfo_job` and
+        :attr:`upload_screenshots_job`, and therefore both jobs must be
+        :attr:`finished <upsies.jobs.base.JobBase.is_finished>`.
+
+        Every key in the returned :class:`dict` is a path to a video file of
+        which ``mediainfo`` was collected and/or screenshots were uploaded.
+
+        Every value is a :class:`dict` with the keys ``mediainfo`` and
+        ``screenshot_urls``.
+
+        ``mediainfo`` is the return value of :func:`~.video.mediainfo` for the
+        corresponding video file.
+
+        ``screenshot_urls`` is a :class:`list` of screenshot URLs for the
+        corresponding video file.
+
+        .. note:: For DVDs (directories with a VIDEO_TS subdirectory), an
+                  ``mediainfo`` includes an .IFO and a .VOB key while
+                  ``screenshot_urls`` is empty for the .IFO key.
+
+                  ``mediainfo`` may also be an empty :class:`str`, for example
+                  if :attr:`mediainfo_from_all_videos` is `False`.
+
+        Season example:
+
+        .. code::
+
+            {
+              "/path/to/season/Foo.S01E01.mkv": {
+                "mediainfo": "<mediainfo for Foo.S01E01.mkv>",
+                "screenshot_urls": [
+                  "https://image.host/Foo.S01E01.mkv.0:48:08.png",
+                  "https://image.host/Foo.S01E01.mkv.1:12:12.png",
+                ]
+              },
+            }
+
+        DVD example:
+
+        .. code::
+
+            {
+              "/path/to/DVD/VIDEO_TS/VTS_01_0.IFO": {
+                "mediainfo": "<mediainfo for VTS_01_0.IFO>",
+                "screenshot_urls": [],
+              }
+              "/path/to/DVD/VIDEO_TS/VTS_01_1.VOB": {
+                "mediainfo": "<mediainfo for VTS_01_1.VOB>",
+                "screenshot_urls": [
+                  "https://image.host/VTS_01_1.VOB.0:14:58.png",
+                  "https://image.host/VTS_01_1.VOB.0:26:12.png"
+                ]
+              }
+            }
+        """
+        mediainfos_and_screenshots = collections.defaultdict(
+            lambda: {
+                'mediainfo': '',
+                'screenshot_urls': [],
+            }
+        )
+
+        # NOTE: Don't expect all mediainfos/screenshots to exist. A fatal
+        #       KeyError traceback is always worse than manually adding missing
+        #       metadata to a semi-successful upload.
+
+        assert self.mediainfo_job.is_finished
+        for video_path, mediainfo in self.mediainfo_job.mediainfos_by_file.items():
+            mediainfos_and_screenshots[video_path]['mediainfo'] = mediainfo
+
+        # `screenshots_count` screenshots for each `video_path`
+        assert self.upload_screenshots_job.is_finished
+        urls_by_file = self.upload_screenshots_job.urls_by_file
+        screenshots_by_file = self.screenshots_job.screenshots_by_file
+        for video_path, screenshot_paths in screenshots_by_file.items():
+            for screenshot_path in screenshot_paths:
+                screenshot_url = urls_by_file.get(screenshot_path, None)
+                if screenshot_url:
+                    mediainfos_and_screenshots[video_path]['screenshot_urls'].append(screenshot_url)
+
+        return dict(mediainfos_and_screenshots)
+
+    @functools.cached_property
     def scene_check_job(self):
         """:class:`~.jobs.scene.SceneCheckJob` instance"""
         common_job_args = self.common_job_args(ignore_cache=True)
@@ -797,3 +887,57 @@ class TrackerJobsBase(abc.ABC):
                 raise RuntimeError(f'Unfinished job: {job.name}')
         else:
             return getattr(job, attribute)
+
+    def get_relative_file_path(self, filepath):
+        """
+        Return `filepath` relative to :attr:`content_path`
+
+        The first path component of the returned path is the last component of
+        :attr:`content_path`.
+
+        :raise ValueError: if logical `filepath` is not a subpath of logical
+            :attr:`content_path` ("logical" means that relative path components
+            are resolved while symbolic links are not resolved to get an
+            absolute path)
+        """
+        filepath_abs = pathlib.Path(filepath).absolute()
+        content_path_parent = pathlib.Path(self.content_path).absolute().parent
+        try:
+            return str(filepath_abs.relative_to(content_path_parent))
+        except ValueError:
+            raise ValueError(f'{str(filepath_abs)!r} is not a subpath of {str(content_path_parent)!r}')
+
+    def make_screenshots_grid(self, screenshots, columns=2, horizontal_spacer='  ', vertical_spacer='\n'):
+        """
+        Return BBcode for screenshots in a grid layout
+
+        :param screenshots: Sequence of :class:`~.imghosts.common.UploadedImage`
+            objects (URLs with a ``thumbnail_url`` attribute)
+        :param int columns: How many columns to split screenshots into
+        :param str horizontal_spacer: String between columns
+        :param str vertical_spacer: String between rows
+
+        :raise RuntimeError: if any screenshot doesn't have a thumbnail
+        """
+        groups = utils.as_groups(
+            screenshots,
+            group_sizes=(columns,),
+            default=None,
+        )
+
+        rows = []
+        for screenshots in groups:
+            cells = []
+            for screenshot in screenshots:
+                # `screenshot` is `None` at the end if the number of screenshots
+                # is not perfectly divisible by `columns`
+                if screenshot is not None:
+                    if screenshot.thumbnail_url is None:
+                        raise RuntimeError(f'No thumbnail for {screenshot}')
+                    cells.append(f'[url={screenshot}][img]{screenshot.thumbnail_url}[/img][/url]')
+
+            # Space between columns
+            rows.append(horizontal_spacer.join(cells))
+
+        # Space between rows
+        return vertical_spacer.join(rows)
