@@ -2,11 +2,10 @@
 Concrete :class:`~.base.TrackerJobsBase` subclass for BHD
 """
 
+import functools
 import io
-import os
 
-from ... import __homepage__, __project_name__, jobs
-from ...utils import as_groups, cached_property, release, string
+from ... import __homepage__, __project_name__, errors, jobs, utils
 from ..base import TrackerJobsBase
 
 import logging  # isort:skip
@@ -15,7 +14,7 @@ _log = logging.getLogger(__name__)
 
 class BhdTrackerJobs(TrackerJobsBase):
 
-    @cached_property
+    @functools.cached_property
     def jobs_before_upload(self):
         return (
             # Background jobs
@@ -63,7 +62,7 @@ class BhdTrackerJobs(TrackerJobsBase):
             # Activate all jobs in jobs_before/after_upload
             return ()
 
-    @cached_property
+    @functools.cached_property
     def category_job(self):
         return jobs.dialog.ChoiceJob(
             name=self.get_job_name('category'),
@@ -81,9 +80,9 @@ class BhdTrackerJobs(TrackerJobsBase):
         )
 
     _autodetect_category_map = {
-        'Movie': lambda release_name: release_name.type is release.ReleaseType.movie,
-        'TV': lambda release_name: release_name.type in (release.ReleaseType.season,
-                                                         release.ReleaseType.episode)
+        'Movie': lambda release_name: release_name.type is utils.release.ReleaseType.movie,
+        'TV': lambda release_name: release_name.type in (utils.release.ReleaseType.season,
+                                                         utils.release.ReleaseType.episode)
     }
 
     def autodetect_category(self, _):
@@ -93,7 +92,7 @@ class BhdTrackerJobs(TrackerJobsBase):
             if is_match(approved_release_name):
                 return label
 
-    @cached_property
+    @functools.cached_property
     def type_job(self):
         return jobs.dialog.ChoiceJob(
             name=self.get_job_name('type'),
@@ -148,7 +147,7 @@ class BhdTrackerJobs(TrackerJobsBase):
             if is_match(approved_release_name):
                 return label
 
-    @cached_property
+    @functools.cached_property
     def source_job(self):
         # 'output' signal is only emitted when job succeeds while 'finished'
         # signal is also emitted when job fails (e.g. when Ctrl-c is pressed)
@@ -188,7 +187,7 @@ class BhdTrackerJobs(TrackerJobsBase):
             if is_match(approved_release_name):
                 return label
 
-    @cached_property
+    @functools.cached_property
     def description_job(self):
         return jobs.dialog.TextFieldJob(
             name=self.get_job_name('description'),
@@ -196,8 +195,10 @@ class BhdTrackerJobs(TrackerJobsBase):
             precondition=self.make_precondition('description_job'),
             prejobs=(
                 self.upload_screenshots_job,
+                self.mediainfo_job,
             ),
             text=self.generate_description,
+            hidden=True,
             autofinish=True,
             read_only=True,
             **self.common_job_args(ignore_cache=True),
@@ -207,35 +208,70 @@ class BhdTrackerJobs(TrackerJobsBase):
         'common': {'thumb_width': 350},
     }
 
-    async def generate_description(self):
-        assert self.upload_screenshots_job.is_finished
-
-        rows = []
-        screenshot_groups = as_groups(
-            self.upload_screenshots_job.uploaded_images,
-            group_sizes=(2,),
-            default=None,
-        )
-        for screenshots in screenshot_groups:
-            cells = []
-            for screenshot in screenshots:
-                if screenshot is not None:
-                    if screenshot.thumbnail_url is None:
-                        raise RuntimeError(f'No thumbnail for {screenshot}')
-                    cells.append(f'[url={screenshot}][img]{screenshot.thumbnail_url}[/img][/url]')
-
-            # Space between columns
-            rows.append('   '.join(cells))
-
-        screenshots = '[center]\n' + '\n\n'.join(rows) + '\n[/center]'
-        promotion = (
+    def generate_description(self):
+        screenshot_tags = self._generate_description_screenshots()
+        mediainfo_tags = self._generate_description_mediainfos()
+        promotion_tag = (
             '[align=right][size=1]'
             f'Shared with [url={__homepage__}]{__project_name__}[/url]'
             '[/size][/align]'
         )
-        return screenshots + '\n\n' + promotion
 
-    @cached_property
+        description_parts = [
+            '[center]\n'
+            + screenshot_tags
+            + '\n[/center]'
+        ]
+        if mediainfo_tags:
+            # Include mediainfos if there are multiple (e.g. for IFO/VOB or if
+            # `mediainfo_from_all_videos` is True)
+            description_parts.append(
+                '\n'
+                + '[center][h3]Mediainfo[/h3][/center]\n'
+                + mediainfo_tags
+            )
+        description_parts.append(f'\n\n{promotion_tag}')
+
+        return ''.join(description_parts)
+
+    def _generate_description_screenshots(self):
+        assert self.upload_screenshots_job.is_finished
+        return self.make_screenshots_grid(
+            screenshots=self.upload_screenshots_job.uploaded_images,
+            columns=2,
+            horizontal_spacer='   ',
+            vertical_spacer='\n\n',
+        )
+
+    def _generate_description_mediainfos(self):
+        mediainfo_tags = []
+        for video_filepath, mediainfo in self._description_mediainfos.items():
+            filetitle = self.get_relative_file_path(video_filepath)
+            mediainfo_tags.append(
+                f'[hide={filetitle}][code]{mediainfo}[/code][/hide]'
+            )
+        return '\n'.join(mediainfo_tags)
+
+    @property
+    def _description_mediainfos(self):
+        # If there are multiple files in the release, mediainfo for each file is
+        # put in the description. Otherwise, the only needed mediainfo is passed
+        # separately from the description
+        assert self.mediainfo_job.is_finished
+        mediainfos_by_file = self.mediainfo_job.mediainfos_by_file
+        if len(mediainfos_by_file) >= 2:
+            return {
+                filepath: mediainfo
+                for filepath, mediainfo in mediainfos_by_file.items()
+                if mediainfo
+            }
+        else:
+            return {}
+
+    mediainfo_from_all_videos = False
+    screenshots_from_all_videos = False
+
+    @functools.cached_property
     def tags_job(self):
         return jobs.dialog.TextFieldJob(
             name=self.get_job_name('tags'),
@@ -309,7 +345,7 @@ class BhdTrackerJobs(TrackerJobsBase):
             'live': '0' if self.options['draft'] else '1',
         }
 
-    @cached_property
+    @functools.cached_property
     def post_data_edition(self):
         # The edition of the uploaded release. (Collector, Director, Extended,
         # Limited, Special, Theatrical, Uncut or Unrated)
@@ -336,7 +372,7 @@ class BhdTrackerJobs(TrackerJobsBase):
     def post_data_pack(self):
         # The TV pack flag for when the torrent contains a complete season.
         # (0 = No TV pack or 1 = TV Pack). Default is 0
-        if self.release_name.type is release.ReleaseType.season:
+        if self.release_name.type is utils.release.ReleaseType.season:
             return '1'
         else:
             return '0'
@@ -356,24 +392,16 @@ class BhdTrackerJobs(TrackerJobsBase):
 
     @property
     def post_data_nfo(self):
-        # The NFO of the torrent as string.
-        if os.path.isdir(self.content_path):
-            for entry in os.listdir(self.content_path):
-                if entry.lower().endswith('.nfo'):
-                    nfo_path = os.path.join(self.content_path, entry)
-                    # Limit size to 500kB
-                    if os.path.getsize(nfo_path) <= self.max_nfo_size:
-                        try:
-                            with open(nfo_path, 'rb') as f:
-                                return string.autodecode(f.read())
-                        except OSError as e:
-                            self.error(e.strerror if e.strerror else str(e))
+        try:
+            return utils.string.read_nfo(self.content_path)
+        except errors.ContentError as e:
+            self.error(e)
 
     @property
     def post_data_special(self):
         # The TV special flag for when the torrent contains a TV special. (0 =
         # Not a TV special, 1 = TV Special). Default is 0
-        if self.release_name.type is release.ReleaseType.episode:
+        if self.release_name.type is utils.release.ReleaseType.episode:
             if self.options['special']:
                 return '1'
         return '0'
