@@ -44,14 +44,10 @@ class BhdTracker(TrackerBase):
     TrackerConfig = BhdTrackerConfig
     TrackerJobs = BhdTrackerJobs
 
-    async def login(self):
+    async def _login(self):
         pass
 
-    @property
-    def is_logged_in(self):
-        return True
-
-    async def logout(self):
+    async def _logout(self):
         pass
 
     async def get_announce_url(self):
@@ -61,10 +57,20 @@ class BhdTracker(TrackerBase):
         ))
 
     def get_upload_url(self):
-        return '/'.join((
-            self.options['upload_url'].rstrip('/'),
-            self.options['apikey'],
-        ))
+        """
+        Return URL for torrent uploads (includes API key)
+
+        :raise RequestError: if ``apikey`` option is not set
+        """
+        if not self.options['apikey']:
+            # We raise RequestError because this method should only be used by
+            # upload(), which should only raise RequestError
+            raise errors.RequestError(f'trackers.{self.name}.apikey is not set')
+        else:
+            return '/'.join((
+                self.options['upload_url'].rstrip('/'),
+                self.options['apikey'],
+            ))
 
     DRAFT_UPLOADED_MESSAGE = 'Draft uploaded'
 
