@@ -3,10 +3,10 @@ Dummy tracker for testing and debugging
 """
 
 import asyncio
+import functools
 import os
 
 from .. import errors, jobs, utils
-from ..utils import cached_property
 from . import base
 
 import logging  # isort:skip
@@ -55,7 +55,7 @@ class DummyTrackerJobs(base.TrackerJobsBase):
     torrent_piece_size_min = 4 * 2**20  # 4 MiB
     torrent_piece_size_max = 8 * 2**20  # 8 MiB
 
-    @cached_property
+    @functools.cached_property
     def jobs_before_upload(self):
         return (
             self.create_torrent_job,
@@ -70,7 +70,7 @@ class DummyTrackerJobs(base.TrackerJobsBase):
             self.scene_check_job,
         )
 
-    @cached_property
+    @functools.cached_property
     def category_job(self):
         if not self.options['skip_category']:
             return jobs.dialog.ChoiceJob(
