@@ -2,10 +2,10 @@
 Concrete :class:`~.base.TrackerJobsBase` subclass for MTV
 """
 
+import functools
 import re
 
 from ... import __homepage__, __project_name__, jobs, utils
-from ...utils import cached_property
 from ...utils.release import ReleaseType
 from ..base import TrackerJobsBase
 
@@ -17,7 +17,7 @@ class MtvTrackerJobs(TrackerJobsBase):
 
     torrent_piece_size_max = 8 * 2**20  # 8 MiB
 
-    @cached_property
+    @functools.cached_property
     def jobs_before_upload(self):
         return (
             # Background jobs
@@ -53,7 +53,7 @@ class MtvTrackerJobs(TrackerJobsBase):
             # Activate all jobs
             return ()
 
-    @cached_property
+    @functools.cached_property
     def category_job(self):
         return jobs.dialog.ChoiceJob(
             name=self.get_job_name('category'),
@@ -64,9 +64,22 @@ class MtvTrackerJobs(TrackerJobsBase):
                 (c['label'], c['value'])
                 for c in self._categories
             ],
+            callbacks={
+                'finished': self.update_imdb_query,
+            },
             **self.common_job_args(),
         )
 
+    def update_imdb_query(self, category_job_):
+        """
+        Set :attr:`~.webdbs.common.Query.type` on
+        :attr:`~.TrackerJobsBase.imdb_job` to :attr:`chosen_release_type`
+        """
+        old_type = self.imdb_job.query.type
+        new_type = self.chosen_release_type
+        _log.debug('Updating IMDb query from %s to %s', old_type, new_type)
+        self.imdb_job.query.type = new_type
+
     _categories = (
         {'label': 'HD Season', 'value': '5', 'type': ReleaseType.season},
         {'label': 'HD Episode', 'value': '3', 'type': ReleaseType.episode},
@@ -123,7 +136,7 @@ class MtvTrackerJobs(TrackerJobsBase):
         },
     }
 
-    @cached_property
+    @functools.cached_property
     def title_job(self):
         """
         :class:`~.jobs.dialog.TextFieldJob` instance with text set to the
@@ -161,7 +174,11 @@ class MtvTrackerJobs(TrackerJobsBase):
         await self.release_name.fetch_info(webdb=self.imdb, webdb_id=self.imdb_id)
         return str(self.release_name)
 
-    @cached_property
+    image_host_config = {
+        'common': {'thumb_width': 300},
+    }
+
+    @functools.cached_property
     def description_job(self):
         return jobs.dialog.TextFieldJob(
             name=self.get_job_name('description'),
@@ -181,36 +198,37 @@ class MtvTrackerJobs(TrackerJobsBase):
         )
 
     async def generate_description(self):
-        assert self.mediainfo_job.is_finished
-        assert self.upload_screenshots_job.is_finished
+        sections = []
+        section = []
+        for video_path, info in self.mediainfos_and_screenshots.items():
+            if info['mediainfo']:
+                section.append(
+                    f'[mediainfo]{info["mediainfo"]}[/mediainfo]\n'
+                )
 
-        mediainfo = (
-            '[mediainfo]'
-            + self.get_job_output(self.mediainfo_job, slice=0)
-            + '[/mediainfo]'
-        )
-
-        screenshots = []
-        for screenshot in self.upload_screenshots_job.uploaded_images:
-            screenshots.append(f'[img]{screenshot}[/img]')
-
-        screenshots_wrapped = (
-            '[spoiler=Screenshots][center]'
-            + '\n'.join(screenshots)
-            + '[/center][/spoiler]'
-        )
+            if info['screenshot_urls']:
+                section.append((
+                    '[center]'
+                    + self.make_screenshots_grid(
+                        screenshots=info['screenshot_urls'],
+                        columns=2,
+                        horizontal_spacer='    ',
+                        vertical_spacer='\n\n',
+                    )
+                    + '[/center]'
+                ))
+                sections.append(''.join(section))
+                section.clear()
 
+        description = '\n[hr]\n'.join(sections)
         promotion = (
             '[align=right][size=1]'
             f'Shared with [url={__homepage__}]{__project_name__}[/url]'
             '[/size][/align]'
         )
-
         return (
-            mediainfo
-            + '\n\n'
-            + screenshots_wrapped
-            + '\n\n'
+            description
+            + '\n'
             + promotion
         )
 
@@ -229,8 +247,6 @@ class MtvTrackerJobs(TrackerJobsBase):
             'taglist': '',
             'autocomplete_toggle': 'on',
             'image': '',
-            'fontfont': '-1',
-            'fontsize': '-1',
             'desc': '',
             'fontfont': '-1',
             'fontsize': '-1',
@@ -250,8 +266,6 @@ class MtvTrackerJobs(TrackerJobsBase):
             'genre_tags': '---',
             'autocomplete_toggle': 'on',
             'image': '',
-            'fontfont': '-1',
-            'fontsize': '-1',
             'desc': self.get_job_output(self.description_job, slice=0),
             'fontfont': '-1',
             'fontsize': '-1',
