@@ -29,7 +29,7 @@ class NblTrackerConfig(base.TrackerConfigBase):
             ),
         ),
         'source': 'NBL',
-        'exclude': [],
+        'exclude': (),
     }
 
     argument_definitions = {
