@@ -19,9 +19,13 @@ class PtpTrackerConfig(TrackerConfigBase):
         ),
         'source': 'PTP',
         'image_host': types.Choice('ptpimg', options=imghosts.imghost_names()),
-        'screenshots': configfiles.config_value(
+        'screenshots_from_movie': configfiles.config_value(
             value=types.Integer(3, min=3, max=10),
-            description='How many screenshots to make.',
+            description='How many screenshots to make for single-video uploads.',
+        ),
+        'screenshots_from_episode': configfiles.config_value(
+            value=types.Integer(2, min=2, max=10),
+            description='How many screenshots to make per video for multi-video uploads.',
         ),
         'exclude': (
             r'\.(?i:nfo|txt|jpg|jpeg|png|sfv|md5)$',
@@ -41,13 +45,8 @@ class PtpTrackerConfig(TrackerConfigBase):
                 'action': 'store_true',
             },
             ('--screenshots', '--ss'): {
-                'help': ('How many screenshots to make '
-                         f'(min={defaults["screenshots"].min}, '
-                         f'max={defaults["screenshots"].max})'),
-                'type': argtypes.number_of_screenshots(
-                    min=defaults['screenshots'].min,
-                    max=defaults['screenshots'].max,
-                ),
+                'help': 'How many screenshots to make per video file',
+                'type': argtypes.number_of_screenshots(min=1, max=10),
             },
             ('--upload-token', '--ut'): {
                 'help': 'Upload token from staff',
