@@ -2,10 +2,10 @@
 Concrete :class:`~.base.TrackerJobsBase` subclass for PTP
 """
 
+import functools
 from datetime import datetime
 
 from ... import errors, jobs, utils
-from ...utils import cached_property
 from ...utils.release import ReleaseType
 from ..base import TrackerJobsBase
 from ._ptp_tags import PTP_TAGS
@@ -16,7 +16,7 @@ _log = logging.getLogger(__name__)
 
 class PtpTrackerJobs(TrackerJobsBase):
 
-    @cached_property
+    @functools.cached_property
     def jobs_before_upload(self):
         return (
             # Common background jobs
@@ -25,6 +25,7 @@ class PtpTrackerJobs(TrackerJobsBase):
             self.screenshots_job,
             self.upload_screenshots_job,
             self.ptp_group_id_job,
+            self.description_job,
 
             # Common interactive jobs
             self.type_job,
@@ -32,16 +33,14 @@ class PtpTrackerJobs(TrackerJobsBase):
             self.title_job,
             self.scene_check_job,
 
-            # Jobs that only run if movie exists on PTP and we add a release
-
-            # Jobs that only run if movie does not exists on PTP yet
+            # Interactive jobs that only run if movie does not exists on PTP yet
             self.year_job,
             self.plot_job,
             self.tags_job,
             self.cover_art_job,
         )
 
-    @cached_property
+    @functools.cached_property
     def type_job(self):
         return jobs.dialog.ChoiceJob(
             name=self.get_job_name('type'),
@@ -63,20 +62,108 @@ class PtpTrackerJobs(TrackerJobsBase):
         if self.release_name.type == ReleaseType.season:
             return 'Miniseries'
 
+        # Short film if runtime 45 min or less (Rule 1.1.1)
+        # NOTE: This doesn't work for VIDEO_TS releases. We could sum the
+        #       duration of all .VOB files, but they notoriously lie about their
+        #       duration. For now, the user can always correct the autodetected
+        #       type.
         main_video = utils.video.filter_main_videos(
             tuple(utils.video.find_videos(self.content_path))
         )[0]
-
-        # Short film if runtime 45 min or less (Rule 1.1.1)
         if utils.video.duration(main_video) <= 45 * 60:
             return 'Short Film'
 
+    @functools.cached_property
+    def description_job(self):
+        return jobs.dialog.TextFieldJob(
+            name=self.get_job_name('description'),
+            label='Description',
+            prejobs=(
+                self.mediainfo_job,
+                self.upload_screenshots_job,
+            ),
+            text=self.generate_description,
+            autofinish=True,
+            read_only=True,
+            hidden=True,
+            precondition=self.make_precondition('description_job'),
+            **self.common_job_args(ignore_cache=True),
+        )
+
+    async def generate_description(self):
+        original_release_name = (
+            '[size=4]'
+            + '[b]'
+            + utils.fs.basename(
+                utils.fs.strip_extension(self.content_path)
+            )
+            + '[/b]'
+            + '[/size]'
+        )
+
+        # Join mediainfos + screenshots for each movie/episode into
+        # sections. Each section may contain multiple mediainfos (.IFO/.VOB).
+        tags = []
+        subtags = []
+        for video_path, info in self.mediainfos_and_screenshots.items():
+            if info['mediainfo']:
+                subtags.append(f'[mediainfo]{info["mediainfo"]}[/mediainfo]')
+            if info['screenshot_urls']:
+                subtags.append('\n'.join(
+                    f'[img={url}]'
+                    for url in info['screenshot_urls']
+                ))
+                tags.append(''.join(subtags))
+                subtags.clear()
+
+        description = (
+            original_release_name
+            + '\n\n'
+            + '\n[hr]\n'.join(tags)
+        )
+        return description
+
+    mediainfo_from_all_videos = True
+    screenshots_from_all_videos = True
+
+    @functools.cached_property
+    def screenshots_count(self):
+        """
+        How many screenshots to make
+
+        Use :attr:`options`\\ ``["screenshots"]`` it it exists. This value
+        should be explicitly set by the user, e.g. via a CLI argument or GUI
+        element.
+
+        Use :attr:`options`\\ ``["screenshots_from_movie"]`` for uploads that
+        contain a single video file.
+
+        Use :attr:`options`\\ ``["screenshots_from_episode"]`` for uploads that
+        contain multiple video files.
+        """
+        # CLI option, GUI widget, etc
+        if self.options.get('screenshots'):
+            return self.options['screenshots']
+
+        # Get that same video files that were passed to ScreenshotsJob in
+        # JobBase.screenshots_job.
+        video_files = utils.torrent.filter_files(
+            self.content_path,
+            exclude=self.exclude_files,
+        )
+        # Exclude samples, extras, DVD menus, etc
+        video_files = utils.video.filter_main_videos(video_files)
+        if len(video_files) == 1:
+            return self.options['screenshots_from_movie']
+        else:
+            return self.options['screenshots_from_episode']
+
     @property
     def imdb_id(self):
         if self.imdb_job.is_finished:
             return self.imdb_job.output[0]
 
-    @cached_property
+    @functools.cached_property
     def ptp_group_id_job(self):
         return jobs.custom.CustomJob(
             name=self.get_job_name('ptp-group-id'),
@@ -105,7 +192,7 @@ class PtpTrackerJobs(TrackerJobsBase):
             if self.ptp_group_id_job.output:
                 return self.ptp_group_id_job.output[0]
 
-    @cached_property
+    @functools.cached_property
     def title_job(self):
         return jobs.dialog.TextFieldJob(
             name=self.get_job_name('title'),
@@ -131,7 +218,7 @@ class PtpTrackerJobs(TrackerJobsBase):
         if not text:
             raise ValueError('Title must not be empty')
 
-    @cached_property
+    @functools.cached_property
     def year_job(self):
         return jobs.dialog.TextFieldJob(
             name=self.get_job_name('year'),
@@ -162,7 +249,7 @@ class PtpTrackerJobs(TrackerJobsBase):
             if not 1800 < year < datetime.now().year + 10:
                 raise ValueError('Year is not reasonable')
 
-    @cached_property
+    @functools.cached_property
     def tags_job(self):
         return jobs.dialog.TextFieldJob(
             name=self.get_job_name('tags'),
@@ -188,10 +275,11 @@ class PtpTrackerJobs(TrackerJobsBase):
 
     def validate_tags(self, text):
         for tag in text.split(','):
-            if tag.strip() not in PTP_TAGS:
+            tag = tag.strip()
+            if tag and tag not in PTP_TAGS:
                 raise ValueError(f'Tag is not valid: {tag}')
 
-    @cached_property
+    @functools.cached_property
     def cover_art_job(self):
         return jobs.dialog.TextFieldJob(
             name=self.get_job_name('cover_art'),
@@ -209,7 +297,7 @@ class PtpTrackerJobs(TrackerJobsBase):
         assert self.imdb_job.is_finished
         return await self.tracker.get_ptp_metadata(self.imdb_id, key='art')
 
-    @cached_property
+    @functools.cached_property
     def plot_job(self):
         return jobs.dialog.TextFieldJob(
             name=self.get_job_name('plot'),
@@ -274,7 +362,6 @@ class PtpTrackerJobs(TrackerJobsBase):
             # 'remaster_year': ...,
             # 'remaster_other_input': ...,
 
-            # 'nfo_text': releaseInfo.Nfo,
             # 'subtitles[]': releaseInfo.Subtitles,
             # 'trumpable[]': releaseInfo.Trumpable,
 
@@ -285,8 +372,11 @@ class PtpTrackerJobs(TrackerJobsBase):
             # Is scene Release (bool)
             'scene': '1' if self.get_job_attribute(self.scene_check_job, 'is_scene_release') else None,
 
+            # .nfo file content
+            # 'nfo_text': ...,
+
             # Upload token from staff
-            'uploadtoken': self.options['upload_token'] if self.options['upload_token'] else None,
+            'uploadtoken': self.options.get('upload_token', None),
         }
 
         # Tick "Edition Information" checkbox?
@@ -301,12 +391,14 @@ class PtpTrackerJobs(TrackerJobsBase):
 
     @property
     def _post_data_add_format(self):
+        # Upload release to movie that exists on PTP
         return {
             'groupid': self.ptp_group_id,
         }
 
     @property
     def _post_data_add_movie(self):
+        # Upload movie that is not on PTP yet in any format
         post_data = {
             'imdb': self.tracker.normalize_imdb_id(self.imdb_id),
             'title': self.get_job_output(self.title_job, slice=0),
