@@ -2,6 +2,8 @@
 Generate properly formatted release name
 """
 
+import functools
+
 from .... import errors, jobs, utils
 from .base import CommandBase
 
@@ -32,18 +34,18 @@ class release_name(CommandBase):
         },
     }
 
-    @utils.cached_property
+    @functools.cached_property
     def jobs(self):
         return (self.imdb_job, self.release_name_job)
 
-    @utils.cached_property
+    @functools.cached_property
     def release_name(self):
         return utils.release.ReleaseName(
             self.args.RELEASE,
             separator=self.args.separator,
         )
 
-    @utils.cached_property
+    @functools.cached_property
     def release_name_job(self):
         return jobs.dialog.TextFieldJob(
             name='release-name',
@@ -64,7 +66,7 @@ class release_name(CommandBase):
             ),
         )
 
-    @utils.cached_property
+    @functools.cached_property
     def imdb_job(self):
         # To be able to fetch the original title, year, etc, we need to ask for
         # an ID first. IMDb seems to be best.
@@ -77,6 +79,6 @@ class release_name(CommandBase):
             callbacks={'output': self._update_release_name},
         )
 
-    @utils.cached_property
+    @functools.cached_property
     def imdb(self):
         return utils.webdbs.webdb('imdb')
