@@ -2,6 +2,8 @@
 Create screenshots from video file and optionally upload them
 """
 
+import functools
+
 from .... import jobs, utils
 from .base import CommandBase
 
@@ -60,7 +62,7 @@ class screenshots(CommandBase):
         },
     }
 
-    @utils.cached_property
+    @functools.cached_property
     def screenshots_job(self):
         return jobs.screenshots.ScreenshotsJob(
             home_directory=self.args.output_directory,
@@ -76,7 +78,7 @@ class screenshots(CommandBase):
             from_all_videos=self.args.from_all_videos,
         )
 
-    @utils.cached_property
+    @functools.cached_property
     def upload_screenshots_job(self):
         if self.args.upload_to:
             imghost_job = jobs.imghost.ImageHostJob(
@@ -98,7 +100,7 @@ class screenshots(CommandBase):
             self.screenshots_job.signal.register('finished', lambda _: imghost_job.finalize())
             return imghost_job
 
-    @utils.cached_property
+    @functools.cached_property
     def jobs(self):
         return (
             self.screenshots_job,
