@@ -2,6 +2,8 @@
 Generate all required metadata and upload to tracker
 """
 
+import functools
+
 import aiobtclientapi
 
 from .... import __project_name__, constants, jobs, trackers, utils
@@ -92,7 +94,7 @@ class submit(base.CommandBase):
         for tracker in trackers.trackers()
     }
 
-    @utils.cached_property
+    @functools.cached_property
     def jobs(self):
         submit_job = jobs.submit.SubmitJob(
             home_directory=self.home_directory,
@@ -107,12 +109,12 @@ class submit(base.CommandBase):
             + tuple(self.tracker_jobs.jobs_after_upload)
         )
 
-    @utils.cached_property
+    @functools.cached_property
     def tracker_name(self):
         """Lower-case abbreviation of tracker name"""
         return self.args.subcommand.lower()
 
-    @utils.cached_property
+    @functools.cached_property
     def tracker_options(self):
         """
         :attr:`tracker_name` section in trackers configuration file combined with
@@ -121,7 +123,7 @@ class submit(base.CommandBase):
         """
         return self.get_options('trackers', self.tracker_name)
 
-    @utils.cached_property
+    @functools.cached_property
     def tracker(self):
         """
         :class:`~.trackers.base.TrackerBase` instance from one of the submodules of
@@ -132,7 +134,7 @@ class submit(base.CommandBase):
             options=self.tracker_options,
         )
 
-    @utils.cached_property
+    @functools.cached_property
     def tracker_jobs(self):
         """
         :class:`~.trackers.base.TrackerJobsBase` instance from one of the submodules
