@@ -2,6 +2,7 @@
 Commands related to torrent files
 """
 
+import functools
 import os
 
 import aiobtclientapi
@@ -31,7 +32,7 @@ class torrent_add(CommandBase):
         },
     }
 
-    @utils.cached_property
+    @functools.cached_property
     def jobs(self):
         client_name = self.args.CLIENT
         options = self.get_options('clients', client_name)
@@ -126,7 +127,7 @@ class torrent_create(CommandBase):
         for tracker in trackers.trackers()
     }
 
-    @utils.cached_property
+    @functools.cached_property
     def tracker_name(self):
         return self.args.subcommand.lower()
 
@@ -135,7 +136,7 @@ class torrent_create(CommandBase):
         """Create torrent file in current working directory"""
         return '.'
 
-    @utils.cached_property
+    @functools.cached_property
     def create_torrent_job(self):
         return jobs.torrent.CreateTorrentJob(
             home_directory=self.home_directory,
@@ -158,7 +159,7 @@ class torrent_create(CommandBase):
             ),
         )
 
-    @utils.cached_property
+    @functools.cached_property
     def add_torrent_job(self):
         if self.args.add_to:
             client_name = self.args.add_to
@@ -184,7 +185,7 @@ class torrent_create(CommandBase):
             self.create_torrent_job.signal.register('finished', lambda _: add_torrent_job.finalize())
             return add_torrent_job
 
-    @utils.cached_property
+    @functools.cached_property
     def copy_torrent_job(self):
         if self.args.copy_to:
             copy_torrent_job = jobs.torrent.CopyTorrentJob(
@@ -199,7 +200,7 @@ class torrent_create(CommandBase):
             self.create_torrent_job.signal.register('finished', lambda _: copy_torrent_job.finalize())
             return copy_torrent_job
 
-    @utils.cached_property
+    @functools.cached_property
     def jobs(self):
         return (
             self.create_torrent_job,
