@@ -2,6 +2,8 @@
 Search online database like IMDb to get an ID
 """
 
+import functools
+
 from .... import jobs, utils
 from .base import CommandBase
 
@@ -42,7 +44,7 @@ class webdb_search(CommandBase):
         },
     }
 
-    @utils.cached_property
+    @functools.cached_property
     def jobs(self):
         return (
             jobs.webdb.WebDbSearchJob(
