@@ -1,4 +1,5 @@
-from ....utils import cached_property
+import functools
+
 from . import JobWidgetBase
 
 # This job is hidden so we only need a dummy widget.
@@ -7,6 +8,6 @@ class SetJobWidget(JobWidgetBase):
     def setup(self):
         pass
 
-    @cached_property
+    @functools.cached_property
     def runtime_widget(self):
         return None
