@@ -1,4 +1,5 @@
-from ....utils import cached_property
+import functools
+
 from .. import widgets
 from . import JobWidgetBase
 
@@ -18,6 +19,6 @@ class ImageHostJobWidget(JobWidgetBase):
             self._upload_progress.percent = self.job.images_uploaded / self.job.images_total * 100
             self.invalidate()
 
-    @cached_property
+    @functools.cached_property
     def runtime_widget(self):
         return self._upload_progress
