@@ -4,6 +4,7 @@ File system helpers
 
 import functools
 import os
+import pathlib
 import re
 import time
 
@@ -181,7 +182,7 @@ def mkdir(path):
         assert_dir_usable(path)
 
 
-def basename(path):
+def basename(path, parents=0):
     """
     Return last segment in `path`
 
@@ -192,8 +193,17 @@ def basename(path):
     ''
     >>> upsies.utils.basename('a/b/c/')
     'c'
+
+    :param parents: How many levels of parent directories to include in the
+        returned path
     """
-    return os.path.basename(str(path).rstrip(os.sep))
+    basename = os.path.basename(str(path).rstrip(os.sep))
+    parent_parts = list(pathlib.Path(str(path)).parent.parts)
+    parents_to_include = []
+    for _ in range(parents):
+        if parent_parts:
+            parents_to_include.insert(0, parent_parts.pop(-1))
+    return str(pathlib.Path(*parents_to_include).joinpath(basename))
 
 
 def dirname(path):
