@@ -12,8 +12,8 @@ import os
 import pathlib
 import random
 import re
-import time
 import ssl
+import time
 
 import httpx
 
@@ -57,6 +57,7 @@ async def get(
         max_cache_age=float('inf'),
         user_agent=False,
         follow_redirects=True,
+        verify=True,
         timeout=_default_timeout,
         cookies=None,
         debug_file=None,
@@ -74,6 +75,8 @@ async def get(
     :param int,float max_cache_age: Maximum age of cache in seconds
     :param bool user_agent: Whether to send the User-Agent header
     :param bool follow_redirects: Whether to follow redirects
+    :param bool verify: Whether to verify TLS connection or ignore any errors
+        like expired certificate
     :param int,float timeout: Maximum number of seconds the request may take
     :param cookies: Cookies to include in the request (merged with
         existing cookies in the global client session)
@@ -100,6 +103,7 @@ async def get(
         max_cache_age=max_cache_age,
         user_agent=user_agent,
         follow_redirects=follow_redirects,
+        verify=verify,
         timeout=timeout,
         cookies=cookies,
         debug_file=debug_file,
@@ -115,6 +119,7 @@ async def post(
         max_cache_age=float('inf'),
         user_agent=False,
         follow_redirects=True,
+        verify=True,
         timeout=_default_timeout,
         cookies=None,
         debug_file=None,
@@ -164,6 +169,8 @@ async def post(
     :param int,float max_cache_age: Maximum age of cache in seconds
     :param bool user_agent: Whether to send the User-Agent header
     :param bool follow_redirects: Whether to follow redirects
+    :param bool verify: Whether to verify TLS connection or ignore any errors
+        like expired certificate
     :param int,float timeout: Maximum number of seconds the request may take
     :param cookies: Cookies to include in the request (merged with existing
         cookies in the global client session); see :func:`get`
@@ -183,6 +190,7 @@ async def post(
         max_cache_age=max_cache_age,
         user_agent=user_agent,
         follow_redirects=follow_redirects,
+        verify=verify,
         timeout=timeout,
         cookies=cookies,
         debug_file=debug_file,
@@ -281,6 +289,7 @@ async def _request(
         max_cache_age=float('inf'),
         user_agent=False,
         follow_redirects=True,
+        verify=True,
         timeout=_default_timeout,
         cookies=None,
         debug_file=None,
@@ -291,6 +300,7 @@ async def _request(
     client = httpx.AsyncClient(
         headers={**_default_headers, **headers},
         cookies=_load_permanent_cookies(cookies),
+        verify=bool(verify),
     )
     async with client:
         # Create request object
@@ -363,7 +373,7 @@ async def _request(
                     msg = e.strerror
                 else:
                     msg = str(e)
-                raise errors.RequestError(f'{url}: {msg}')
+                raise errors.RequestError(f'{url}: TLS: {msg}')
 
             except httpx.HTTPError as e:
                 _log.debug(f'Unexpected HTTP error: {e!r}')
@@ -648,10 +658,7 @@ def _get_user_agent_from_cache():
     cache_filepath = _get_user_agent_cache_filepath()
     if os.path.exists(cache_filepath):
         cache_created = os.stat(cache_filepath).st_mtime
-        _log.debug('user agent cache created: %r', cache_created)
         cache_age = time.time() - cache_created
-        _log.debug('    user agent cache age: %r', cache_age)
-        _log.debug('user agent cache max age: %r', USER_AGENT_CACHE_MAX_AGE)
         if cache_age < USER_AGENT_CACHE_MAX_AGE:
             try:
                 return open(cache_filepath, 'r').read().strip()
