@@ -26,7 +26,8 @@ def _make_screenshot_cmd(video_file, timestamp, screenshot_file):
     return (
         _ffmpeg_executable(),
         '-y',
-        '-loglevel', 'level+error',
+        '-hide_banner',
+        '-loglevel', 'error',
         '-ss', str(timestamp),
         '-i', utils.video.make_ffmpeg_input(video_file),
         '-vframes', '1',
@@ -103,7 +104,8 @@ def _make_resize_cmd(image_file, dimensions, resized_file):
     return (
         _ffmpeg_executable(),
         '-y',
-        '-loglevel', 'level+error',
+        '-hide_banner',
+        '-loglevel', 'error',
         '-i', f'file:{image_file}',
         '-vf', f'scale={dimensions}:force_original_aspect_ratio=decrease',
         f'file:{resized_file}',
