@@ -5,10 +5,9 @@ Scene release search and verification
 from ... import utils
 from .. import release
 from ..types import SceneCheckResult
-from . import corruptnet, predbde, predbovh, srrdb
+from . import corruptnet, predbclub, predbde, predbovh, srrdb
 from .base import PredbApiBase
-from .common import (assert_not_abbreviated_filename, is_abbreviated_filename,
-                     is_mixed_season_pack)
+from .common import assert_not_abbreviated_filename, is_abbreviated_filename, is_mixed_season_pack
 from .multi import MultiPredbApi
 from .query import SceneQuery
 
