@@ -15,8 +15,6 @@ class MultiPredbApi:
     """
     Wrapper around multiple :class:`~.PredbApiBase` instances
 
-
-
     Each method loops over every provided predb and calls the same method on
     it. The first call that does not raise :class:`~.RequestError` or
     :class:`NotImplementedError` is returned.
@@ -29,7 +27,13 @@ class MultiPredbApi:
     :param predbs: Sequence of :class:`~.PredbApiBase` instances
     """
 
-    DEFAULT_PREDB_NAMES = ('corruptnet', 'srrdb')
+    DEFAULT_PREDB_NAMES = (
+        'srrdb',
+        # 'corruptnet',
+        # 'predbovh',
+        'predbclub',
+        'predbde',
+    )
 
     def __init__(self, predbs=None):
         if predbs:
@@ -95,29 +99,26 @@ class MultiPredbApi:
 
     async def search(self, *args, **kwargs):
         """
-        Search multiple predbs concurrently and combine the results
+        Search multiple predbs concurrently and return first non-empty results
 
         See :meth:`~.PredbApiBase.search`.
         """
-        results = set()
         exceptions = []
-        async for result in self._for_all_predbs('search', *args, **kwargs):
-            if isinstance(result, Exception):
-                exceptions.append(result)
+        async for results in self._for_all_predbs('search', *args, **kwargs):
+            if isinstance(results, Exception):
+                exceptions.append(results)
             else:
-                # Return first non-empty search results.  If a fast-but-
-                # incomplete predb (e.g. corruptnet) finds search results, we
-                # return them quickly. Otherwise,, we wait for a slow-but-
-                # complete predb (e.g. srrdb) to maybe find results.
-                results.update(result)
+                # Return non-empty search results or wait for next response
+                if results:
+                    return results
 
-        if not results and exceptions:
+        if exceptions:
             # All predbs are unreachable or don't have `method_name` implemented.
             # Raise combined RequestErrors.
             self._raise(exceptions, method_name='search')
         else:
             # No search results
-            return sorted(results)
+            return []
 
     async def release_files(self, *args, **kwargs):
         """See :meth:`~.PredbApiBase.release_files`"""
