@@ -21,7 +21,7 @@ import natsort
 import unidecode
 
 from .. import constants, errors, utils
-from . import LazyModule, cached_property, fs, video
+from . import LazyModule, fs, video
 from .types import ReleaseType
 
 import logging  # isort:skip
@@ -844,17 +844,18 @@ class ReleaseName(collections.abc.Mapping):
 
         joined = ' '.join(parts) + f'-{self.group}'
 
+        # Separator (usually " " or ".")
         sep = separator if separator is not None else self.separator
+        if sep != ' ':
+            joined = joined.replace(' ', sep)
+
         if sep == '.':
             # Remove non-word characters like (e.g.: ,:) with some exceptions
             joined = re.sub(r'[^ \w\.-]', '', joined)
+            # Deduplicate "."
+            joined = re.sub(r'\.+', '.', joined)
 
-        formatted = joined.replace(' ', sep)
-
-        # Deduplicate "."
-        formatted = re.sub(r'\.+', '.', formatted)
-
-        return formatted
+        return joined
 
 
 class ReleaseInfo(collections.abc.MutableMapping):
@@ -950,7 +951,7 @@ class ReleaseInfo(collections.abc.MutableMapping):
         """`path` argument as :class:`str`"""
         return self._path
 
-    @cached_property
+    @functools.cached_property
     def _guess(self):
         path = self._abspath
 
@@ -1022,7 +1023,7 @@ class ReleaseInfo(collections.abc.MutableMapping):
         r')[ \.]'
     )
 
-    @cached_property
+    @functools.cached_property
     def release_name_params(self):
         """
         Release name without title and year or season/episode info
@@ -1049,7 +1050,7 @@ class ReleaseInfo(collections.abc.MutableMapping):
 
     _title_aka_regex = re.compile(rf'{DELIM}AKA{DELIM}')
 
-    @cached_property
+    @functools.cached_property
     def _title_parts(self):
         # guessit splits AKA at " - ", so we re-join it
         title_parts = [_as_string(self._guess.get('title', ''))]
@@ -1120,7 +1121,7 @@ class ReleaseInfo(collections.abc.MutableMapping):
     }
     _proper_repack_regex = re.compile(rf'(?:{DELIM}|^)((?i:proper|repack\d*))(?:{DELIM}|$)')
     _hdr_regexes = {
-        'Dolby Vision': re.compile(rf'(?:{DELIM}|^)(?i:DV|DoVi|Dolby{DELIM}Vision)(?:{DELIM}|$)'),
+        'DoVi': re.compile(rf'(?:{DELIM}|^)(?i:DV|DoVi|Dolby{DELIM}Vision)(?:{DELIM}|$)'),
         'HDR10+': re.compile(rf'(?:{DELIM}|^)(?i:HDR10\+)(?:{DELIM}|$)'),
         'HDR10': re.compile(rf'(?:{DELIM}|^)(?i:HDR10)(?:[^\+]|$)'),
         'HDR': re.compile(rf'(?:{DELIM}|^)(?i:HDR)(?:[^10\+]|$)'),
