@@ -4,6 +4,7 @@ CLI argument types
 All types return normalized values and raise ValueError for invalid values.
 """
 
+import collections
 import enum
 import re
 
@@ -128,6 +129,14 @@ class Bool(str):
         else:
             return NotImplemented
 
+    def __ne__(self, other):
+        if isinstance(other, type(self)):
+            return other._bool != self._bool
+        elif isinstance(other, bool):
+            return other != self._bool
+        else:
+            return NotImplemented
+
     def __repr__(self):
         return f'{type(self).__name__}({super().__str__()!r})'
 
@@ -288,3 +297,79 @@ class SceneCheckResult(enum.Enum):
 
     def __repr__(self):
         return f'{type(self).__name__}.{self.value}'
+
+
+def RegEx(pattern):
+    """
+    Create :class:`re.Pattern` (return value of :func:`re.compile`)
+
+    :raise ValueError: instead of :class:`re.error`
+    """
+    try:
+        return re.compile(pattern)
+    except re.error as e:
+        orig_msg = str(e)
+        msg = orig_msg[0].upper() + orig_msg[1:]
+        raise ValueError(f'{pattern}: {msg}')
+
+
+def ListOf(item_type, iterable=()):
+    """
+    Immutable list of `item_type` objects
+
+    :param item_type: Any callable that returns a validated object for one of the
+        list items or raises :class:`ValueError` or :class:`TypeError`
+    :param iterable: Any iterable of initial items
+
+        Items in `iterable` are converted with `item_type` as well.
+
+    :raise ValueError: if any invalid value is added to the list
+
+    :return: new instance of a subclass of :class:`~.collections.abc.Sequence`
+    """
+
+    # Avoid NameError bug (https://github.com/python/cpython/issues/87546)
+    item_type_ = item_type
+
+    class ListOf(collections.abc.Sequence):
+
+        item_type = item_type_
+
+        @classmethod
+        def _convert(cls, item):
+            try:
+                return cls.item_type(item)
+            except (ValueError, TypeError):
+                raise ValueError(f'Invalid {cls.item_type.__qualname__} value: {item}')
+
+        def __new__(cls, iterable=()):
+            self = super().__new__(cls)
+            self._seq = tuple(cls._convert(item) for item in iterable)
+            return self
+
+        def __getitem__(self, key):
+            return self._seq[key]
+
+        def __len__(self):
+            return len(self._seq)
+
+        def __eq__(self, other):
+            if isinstance(other, collections.abc.Sequence):
+                return self._seq == tuple(other)
+            else:
+                return NotImplemented
+
+        def __repr__(self):
+            return f'{type(self).__name__}({self._seq!r})'
+
+    # Specify class name for easier debugging (e.g. "ListOfSomeClassName")
+    ListOf.__name__ = (
+        'ListOf'
+        + item_type.__name__[0].upper()
+        + item_type.__name__[1:]
+    )
+    ListOf.__qualname__ = ListOf.__name__
+    ListOf.__doc__ = f"""Immutable list of {item_type_.__qualname__}"""
+
+    # Instantiate custom list with provided items
+    return ListOf(iterable)
