@@ -4,6 +4,7 @@ Video metadata
 
 import collections
 import functools
+import glob
 import json
 import os
 import re
@@ -62,10 +63,18 @@ def mediainfo(path, only_first=True):
         else:
             return mi
 
-    if only_first:
+    if not os.path.isdir(path):
+        # If we get a file path, don't complain if it's not a video file. This
+        # allows us to get mediainfo for .IFO files even though they are not
+        # videos.
+        mediainfo = _run_mediainfo(path)
+        return remove_parent_directory(mediainfo)
+
+    elif only_first:
         video_file = find_videos(path)[0]
         mediainfo = _run_mediainfo(video_file)
         return remove_parent_directory(mediainfo)
+
     else:
         video_files = find_videos(path)
         mediainfos = []
@@ -117,7 +126,7 @@ def _duration_from_mediainfo(video_file_path):
     try:
         return float(tracks['General'][0]['Duration'])
     except (KeyError, IndexError, TypeError, ValueError):
-        raise RuntimeError(f'Unexpected tracks: {tracks!r}')
+        raise RuntimeError(f'Unexpected tracks from {video_file_path}: {tracks!r}')
 
 
 @functools.lru_cache(maxsize=None)
@@ -143,7 +152,7 @@ def _tracks(video_file_path):
     tracks = {}
     try:
         for track in json.loads(stdout)['media']['track']:
-            if not track['@type'] in tracks:
+            if track['@type'] not in tracks:
                 tracks[track['@type']] = []
             tracks[track['@type']].append(track)
         return tracks
@@ -520,7 +529,10 @@ _audio_format_translations = (
     ('DTS', {'Format': re.compile(r'^DTS$'), 'Format_Commercial_IfAny': None}),
     ('DTS-ES', {'Format_Commercial_IfAny': re.compile(r'DTS-ES')}),
     ('DTS-HD', {'Format_Commercial_IfAny': re.compile(r'DTS-HD(?! Master Audio)')}),
-    ('DTS-HD MA', {'Format_Commercial_IfAny': re.compile(r'DTS-HD Master Audio'), 'Format_AdditionalFeatures': re.compile(r'XLL$')}),
+    ('DTS-HD MA', {
+        'Format_Commercial_IfAny': re.compile(r'DTS-HD Master Audio'),
+        'Format_AdditionalFeatures': re.compile(r'XLL$'),
+    }),
     ('DTS:X', {'Format_AdditionalFeatures': re.compile(r'XLL X')}),
     ('FLAC', {'Format': re.compile(r'FLAC')}),
     ('MP3', {'Format': re.compile(r'MPEG Audio')}),
@@ -661,71 +673,65 @@ def find_videos(path):
     """
     Find video files, excluding nfo, screenshots, samples, etc
 
-    Video files are detected by file extension.
-
-    Directories are walked recursively and contents are sorted naturally,
-    e.g. "2.mkv" is sorted before "10.mkv".
-
-    Paths to Blu-ray images (directories that contain a "BDMV" directory) are
+    Paths to Blu-ray trees (directories that contain a "BDMV" directory) are
     simply returned.
 
-    For paths to DVD images (directories that contain a "VIDEO_TS" directory),
-    return the largest bunch of VOB files.
+    If there are any "VIDEO_TS" (DVD) directories beneath `path` and its
+    subdirectories, the largest VOB file for each "VIDEO_TS" directory is
+    returned.
 
     For season packs (i.e. directories that contain files with "S..E.." in their
     name), episodes are returned and all other files are excluded.
 
-    Except for season packs, video files are filtered through
-    :func:`filter_main_videos` to exclude samples and such.
+    In all other cases that are not described above, directories are walked
+    recursively, video files are detected by file extension and sorted naturally
+    (e.g. "2.mkv" is sorted before "10.mkv"), and found video files are filtered
+    through :func:`filter_main_videos` to exclude samples and such.
 
     :param str path: Path to file or directory
 
-    :return: :class:`list` of video file paths
+    :return: Sequence of video file paths
 
-    :raise ContentError: if no video file can be found or if it is unreadable
+    :raise ContentError: if no video file can be found
     """
     def normalize_files(files):
         return natsort.natsorted(str(f) for f in files)
 
-    if os.path.isdir(path) and os.path.isdir(os.path.join(path, 'BDMV')):
-        # Blu-ray image; ffmpeg can read that with the "bluray:" protocol
+    # Blu-ray
+    if os.path.isdir(os.path.join(path, 'BDMV')):
+        # ffmpeg can read BDMV with the "bluray:" protocol
         return normalize_files([path])
 
-    elif os.path.isdir(path) and os.path.isdir(os.path.join(path, 'VIDEO_TS')):
-        # DVD image; ffmpeg can't read that properly so we get a list of .VOBs,
-        # find the largest set (e.g. VTS_02_*.VOB) and use that. We go by file
-        # size instead of duration because we don't want to pick the VOB that is
-        # 20 hours of black (yes, that happened). The largest files should be
-        # those with the most complexity, i.e. the main feature.
-        vob_sets = collections.defaultdict(lambda: [])
-        for filepath in fs.file_list(path, extensions=('VOB',)):
-            set_name = re.sub(r'^(\w+_\d+)_\d+\.VOB$', r'\1', fs.basename(filepath))
-            vob_sets[set_name].append(filepath)
+    # DVD
+    if os.path.isdir(path):
+        # ffmpeg doesn't have a "dvd:" protocol so we return the largest VOB
+        # file in each VIDEO_TS subdirectory beneath `path`
+        files = []
+        for video_ts_path in for_each_video_ts(path):
+            all_vobs = utils.fs.file_list(video_ts_path, extensions=('VOB',))
+            main_vob = find_main_vob(all_vobs)
+            if main_vob:
+                files.append(main_vob)
+        if files:
+            return normalize_files(files)
 
-        # Reverse sort set of VOB files by combined size and pick the first set
-        files = tuple(sorted(
-            vob_sets.values(),
-            key=lambda vobs: sum(fs.file_size(vob) for vob in vobs),
-            reverse=True,
-        )[0])
+    # Directory containing video files or video file
+    files = fs.file_list(path, extensions=constants.VIDEO_FILE_EXTENSIONS)
 
-    else:
-        files = fs.file_list(path, extensions=constants.VIDEO_FILE_EXTENSIONS)
-
-        # Find episodes in season pack by file name to avoid time consuming
-        # call to filter_main_videos()
-        episode_regex = re.compile(
-            rf'(?:^|{release.DELIM})'
-            rf'(?i:S|Season{release.DELIM}?)\d+{release.DELIM}?(?i:E|Episode{release.DELIM}?)\d+'
-            rf'{release.DELIM}'
-        )
-        episodes = [
-            file
-            for file in files
-            if episode_regex.search(os.path.basename(file))
-        ]
-        if episodes:
-            return normalize_files(episodes)
+    # Find episodes in season pack by file name for better accuracy and to avoid
+    # time consuming system calls in filter_main_videos()
+    episode_regex = re.compile(
+        rf'(?:^|{release.DELIM})'
+        rf'(?i:S|Season{release.DELIM}?)\d+{release.DELIM}?(?i:E|Episode{release.DELIM}?)\d+'
+        rf'{release.DELIM}'
+    )
+    episodes = [
+        file
+        for file in files
+        if episode_regex.search(os.path.basename(file))
+    ]
+    if episodes:
+        return normalize_files(episodes)
 
     if not files:
         raise errors.ContentError(f'{path}: No video file found')
@@ -736,14 +742,17 @@ def find_videos(path):
         return normalize_files(considered_files)
 
 
-@functools.lru_cache(maxsize=None)
 def filter_main_videos(video_file_paths):
-    """
-    Filter `video_file_paths` for comparable video duration
+    r"""
+    Filter `video_file_paths` for main video files
 
-    Exclude any videos that are shorter than 50% of the average.
+    Exclude any non-videos (see :const:`~.constants.VIDEO_FILE_EXTENSIONS`) and
+    any videos that are smaller than 75 % of the average file size
+    (e.g. samples).
 
-    This is useful to exclude samples or short .VOBs from DVD images.
+    If `video_file_paths` contains any .VOB files from a DVD (path ends with
+    ``/VIDEO_TS/VTS_\d+_\d+\.VOB``), return the largest .VOB file from each
+    VIDEO_TS directory.
 
     .. note:: Because this function is decorated with
        :func:`functools.lru_cache`, `video_file_paths` should be a tuple (or any
@@ -751,31 +760,164 @@ def filter_main_videos(video_file_paths):
 
     :params video_file_paths: Hashable sequence of video file paths
 
-    :return: Tuple of video file paths
-
-    :raise ContentError: if any path in `video_file_paths` is not readable
+    :return: Filtered subset of `video_file_paths` as a sequence
     """
+    # Single video file
     paths = tuple(video_file_paths)
     if len(paths) < 2:
         return paths
-    else:
-        # There is no guarantee that video files have a duration, especially VOB
-        # files can be weird.
-        def maybe_duration(filepath):
-            try:
-                return _duration(filepath)
-            except RuntimeError:
-                return None
 
-        durations = {fp: maybe_duration(fp) for fp in video_file_paths}
-        durations = {fp: duration for fp, duration in durations.items() if duration}
-        if durations:
-            avg = sum(durations.values()) / len(durations)
-        else:
-            avg = 0
-        min_duration = avg * 0.5
-        return tuple(fp for fp,l in durations.items()
-                     if l >= min_duration)
+    # DVD (VIDEO_TS)
+    main_video_ts_videos = _filter_main_videos_dvd(paths)
+    if main_video_ts_videos:
+        return main_video_ts_videos
+
+    # Exclude non-video files
+    only_video_paths = (
+        fp for fp in paths
+        if utils.fs.file_extension(fp).lower() in constants.VIDEO_FILE_EXTENSIONS
+    )
+    # Get size of each video
+    sizes = {fp: utils.fs.file_size(fp) for fp in only_video_paths}
+    # Exclude video files with no size (fs.file_size() may return `None`)
+    sizes = {fp: size for fp, size in sizes.items() if size}
+
+    # Exclude video files with size below average
+    if sizes:
+        avg = sum(sizes.values()) / len(sizes)
+    else:
+        avg = 0
+    min_size = avg * 0.75
+    return tuple(
+        filepath for filepath, filesize in sizes.items()
+        if filesize >= min_size
+    )
+
+
+def _filter_main_videos_dvd(video_file_paths):
+    vob_sets = collections.defaultdict(lambda: [])
+    # Group files by common VIDEO_TS parent directory
+    for video_file_path in video_file_paths:
+        match = re.search(
+            rf'^(.*{os.sep}VIDEO_TS)({os.sep}VTS_\d+_\d+.[A-Z]+)$',
+            video_file_path,
+        )
+        if match:
+            video_ts_path = match.group(1)
+            vob_sets[video_ts_path].append(video_file_path)
+
+    # Return main VOB file for each VIDEO_TS directory
+    main_vobs = []
+    for video_ts_path_, vob_paths in vob_sets.items():
+        main_vob = find_main_vob(vob_paths)
+        if main_vob:
+            main_vobs.append(main_vob)
+    return main_vobs
+
+
+def find_main_vobs(video_ts_files):
+    """
+    Return largest set of VOB files
+
+    VOB files are split into sets by their file names, ignoring the second
+    number, e.g. ``VTS_01_*.VOB``, ``VTS_02_*.VOB``, ``VTS_03_*.VOB``, etc.
+
+    The largest set of VOB files in bytes is the main set.
+
+    Any other files (e.g. ``VIDEO_TS.*``, ``*.IFO``, ``*.BUP``) are ignored.
+
+    :param video_ts_files: Sequence of files from a DVD'S "VIDEO_TS" directory
+    """
+    all_vobs = (
+        filepath for filepath in video_ts_files
+        if re.search(rf'{os.sep}VIDEO_TS{os.sep}VTS_\d+_\d+\.VOB$', filepath)
+    )
+    vob_sets = collections.defaultdict(lambda: [])
+    for vob_path in all_vobs:
+        # Find the largest sets of VOBs (e.g. VTS_01_*.VOB). We go by file size
+        # instead of duration because we don't want to pick the VOB that is 20
+        # hours of black (yes, that happened). The largest set should be the
+        # main feature because it has the most complexity.
+        vob_name = utils.fs.basename(vob_path)
+        match = re.search(r'^(\w+_\d+)_\d+\.VOB$', vob_name)
+        if match:
+            set_name = match.group(1)
+            vob_sets[set_name].append(vob_path)
+
+    # Sort by VOB sets by combined size (largest first)
+    sorted_vob_sets = sorted(
+        vob_sets.values(),
+        key=lambda vob_paths: sum(
+            # file_size() returns `None` if size can't be determined
+            (utils.fs.file_size(path) or 0)
+            for path in vob_paths
+        ),
+        reverse=True,
+    )
+
+    # Return largest VOB set
+    if sorted_vob_sets:
+        return sorted_vob_sets[0]
+    else:
+        return []
+
+
+def find_main_vob(video_ts_files):
+    """
+    Return largest VOB from the largest set of VOB files
+
+    The main set of VOB files is determined by :func:`find_main_vobs`.
+
+    If there are no VOB files, return `None`.
+
+    :param video_ts_files: Sequence of files from a DVD'S "VIDEO_TS" directory
+    """
+    # Find largest VOB set (e.g. VTS_01_*.VOB)
+    main_vobs = find_main_vobs(video_ts_files)
+    if main_vobs:
+        # Reverse sort VOBs by SIZE to get the largest VOB
+        sorted_main_set = sorted(
+            main_vobs,
+            key=lambda vob_path: utils.fs.file_size(vob_path),
+            reverse=True,
+        )
+        return sorted_main_set[0]
+
+
+def vob2ifo(vob_path):
+    """
+    Translate VOB file to corresponding IFO file
+
+    VOB and IFO files are used in VIDEO_TS directories on DVDs.
+
+    :raise ValueError: if `vob_path` does not match expected naming pattern
+    """
+    filename = utils.fs.basename(vob_path)
+    match = re.search(r'^(VTS_\d+_)\d+\.VOB$', filename)
+    if match:
+        return os.path.join(
+            utils.fs.dirname(vob_path),
+            match.group(1) + '0.IFO',
+        )
+    else:
+        raise ValueError(f'This does not look like a VOB file: {vob_path}')
+
+
+def for_each_video_ts(path):
+    """
+    Iterate over "VIDEO_TS" directories beneath `path`
+
+    Subdirectories of `path` are searched recursively.
+    """
+    video_ts_paths = natsort.natsorted(
+        glob.glob(
+            f'{path}{os.sep}**{os.sep}VIDEO_TS',
+            recursive=True,
+        )
+    )
+    for video_ts_path in video_ts_paths:
+        if os.path.isdir(video_ts_path):
+            yield video_ts_path
 
 
 @functools.lru_cache(maxsize=None)
@@ -787,8 +929,8 @@ def make_ffmpeg_input(path):
       is prepended to `path`.
 
     - If path is a directory and contains a subdirectory named "VIDEO_TS", the
-      longest .VOB file (in seconds) is returned. (ffmpeg does not support DVD
-      directory structures.)
+      largest .VOB file is returned. (ffmpeg does not support DVD directory
+      structures.)
 
     - By default, `path` is returned unchanged.
 
@@ -799,14 +941,14 @@ def make_ffmpeg_input(path):
         return f'bluray:{path}'
 
     # Detect DVD
-    if os.path.exists(os.path.join(path, 'VIDEO_TS')):
+    if os.path.isdir(os.path.join(path, 'VIDEO_TS')):
         # FFmpeg doesn't seem to support reading DVD.  We work around this
         # by finding the first .VOB with a reasonable length.
-        vobs = fs.file_list(os.path.join(path, 'VIDEO_TS'))
+        vobs = fs.file_list(os.path.join(path, 'VIDEO_TS'), extensions=('VOB',))
         _log.debug('All VOBs: %r', vobs)
-        reasonable_vobs = filter_main_videos(vobs)
-        _log.debug('Reasonable VOBs: %r', reasonable_vobs)
-        if reasonable_vobs:
-            return reasonable_vobs[0]
+        main_vobs = filter_main_videos(vobs)
+        _log.debug('Main VOBs: %r', main_vobs)
+        if main_vobs:
+            return main_vobs[0]
 
     return str(path)
