@@ -48,13 +48,20 @@ class ImdbApi(WebDbApiBase):
 
     def sanitize_query(self, query):
         """
-        Remove ``"and"`` from :attr:`.Query.title` because IMDb doesn't find ``"Foo
-        & Bar"`` if we search for ``"Foo and Bar"``. It's seems to work vice
-        versa, i.e. the query ``"Foo and Bar"`` finds ``"Foo & Bar"``, so we
-        keep any ``"&"``.
+        Deal with IMDb-specific quirks
+
+        - Remove ``"and"`` from :attr:`.Query.title` because IMDb doesn't find
+          ``"Foo & Bar"`` if we search for ``"Foo and Bar"``. It's seems to work
+          vice versa, i.e. the query ``"Foo and Bar"`` finds ``"Foo & Bar"``, so
+          we keep any ``"&"``.
+
+        - Replace ``"dont"`` with ``"don't"``, ``"cant"`` with ``"can't"``.
         """
         query = super().sanitize_query(query)
         query.title = re.sub(r'\s(?i:and)(\s)', r'\1', query.title)
+        query.title = re.sub(r'\b(?i:dont)(\b)', "don't", query.title)
+        query.title = re.sub(r'\b(?i:cant)(\b)', "can't", query.title)
+        query.title = re.sub(r'\b(?i:wont)(\b)', "won't", query.title)
         return query
 
     async def search(self, query):
@@ -188,22 +195,16 @@ class ImdbApi(WebDbApiBase):
 
     async def poster_url(self, id, season=None):
         if id and await self.type(id) != ReleaseType.episode:
-            soup = await self._get_soup(f'title/{id}/')
-            a_tag = soup.find(href=re.compile(r'/title/tt\d+/mediaviewer/'))
-            if a_tag:
-                soup = await self._get_soup(a_tag['href'])
-                img_tags = [
-                    tag
-                    for tag in soup.find_all('img', src=re.compile(r'^https?://m.media-amazon.com/images/.*?\.jpg$'))
-                    if (
-                        # Only the main poster has no "peek" class
-                        'peek' not in tag['class']
-                    )
-                ]
-                if img_tags:
-                    url = img_tags[0].get('src')
-                    if url:
-                        return url
+            soup = await self._get_soup(f'title/{id}/reference')
+            tag = soup.select_one('meta [property="og:image"]')
+            if tag:
+                url = tag.get('content')
+                if url:
+                    if '@' in url:
+                        # Remove any cropping instructions and other stuff
+                        url = re.sub(r'@.*(\.\w+)$', r'@\1', url)
+                    return url
+
         return ''
 
     rating_min = 0.0
@@ -235,56 +236,37 @@ class ImdbApi(WebDbApiBase):
     )
 
     async def _runtimes(self, id):
-        runtimes = await self._runtimes_new_design(id)
-        if not runtimes:
-            runtimes = await self._runtimes_old_design(id)
-        return runtimes
-
-    async def _runtimes_new_design(self, id):
-        runtimes = {}
         if id:
             soup = await self._get_soup(f'title/{id}/technical')
-            runtimes_label_tag = soup.find('button', string=re.compile(r'\bRuntime\b'))
-            if runtimes_label_tag:
-                values_tag = runtimes_label_tag.next_sibling
-                if values_tag:
-                    for li_tag in values_tag.find_all('li'):
-                        li_text = ' '.join(li_tag.stripped_strings)
+            label_tags = soup.select('.ipc-metadata-list__item > .ipc-metadata-list-item__label')
+            for tag in label_tags:
+                if 'Runtime' in utils.html.as_text(tag):
+                    values_tag = tag.next_sibling
+                    if values_tag:
+                        return self._parse_runtimes(values_tag)
+        return {}
 
-                        # Examples: 2h 13m (133 min)
-                        #           2h 28m (148 min) (extended) (United States)
-                        #           2h 42m (162 min) 3h 6m (186 min) (director's cut) 3h 35m (215 min) (Ultimate Cut)
-                        #           55m
-                        match = re.search(r'\((\d+)\s*(?:min|m)\)\s*(?:\((.+?)\)|)', li_text)
-                        if not match:
-                            match = re.search(r'^(\d+)\s*(?:min|m)$', li_text)
-
-                        if match:
-                            groups = match.groups()
-                            minutes = int(groups[0])
-                            if len(groups) >= 2:
-                                key = utils.string.capitalize(groups[1]) if groups[1] else 'default'
-                            else:
-                                key = 'default'
-
-                            if not any(regex.search(key) for regex in self._ignored_runtimes_keys):
-                                runtimes[key] = minutes
-
-        return runtimes
-
-    async def _runtimes_old_design(self, id):
+    def _parse_runtimes(self, tag):
         runtimes = {}
-        if id:
-            soup = await self._get_soup(f'title/{id}/technical')
-            runtimes_label_tag = soup.find('td', class_='label', string=re.compile(r'\s*Runtime\s*'))
-            try:
-                text = str(runtimes_label_tag.next_sibling.next_sibling)
-            except AttributeError:
-                text = ''
+        for li_tag in tag.find_all('li'):
+            li_text = ' '.join(li_tag.stripped_strings)
+
+            # Examples: 2h 13m (133 min)
+            #           2h 28m (148 min) (extended) (United States)
+            #           2h 42m (162 min) 3h 6m (186 min) (director's cut) 3h 35m (215 min) (Ultimate Cut)
+            #           55m
+            match = re.search(r'\((\d+)\s*(?:min|m)\)\s*(?:\((.+?)\)|)', li_text)
+            if not match:
+                match = re.search(r'^(\d+)\s*(?:min|m)$', li_text)
+
+            if match:
+                groups = match.groups()
+                minutes = int(groups[0])
+                if len(groups) >= 2:
+                    key = utils.string.capitalize(groups[1]) if groups[1] else 'default'
+                else:
+                    key = 'default'
 
-            for match in re.finditer(r'.*\s+\(?(\d+)\s+min\)?\s*(?:\((.*?)\)|)', text):
-                minutes = int(match.group(1))
-                key = utils.string.capitalize(match.group(2)) if match.group(2) else 'default'
                 if not any(regex.search(key) for regex in self._ignored_runtimes_keys):
                     runtimes[key] = minutes
 
@@ -327,7 +309,7 @@ class ImdbApi(WebDbApiBase):
         # /title/tt.../releaseinfo/#akas: Find "(original title)" row in table
         # Example: https://www.imdb.com/title/tt1405737/releaseinfo/#akas
         soup = await self._get_soup(f'title/{id}/releaseinfo')
-        for tag in soup.find_all('button', attrs={'class': 'ipc-metadata-list-item__label'}):
+        for tag in soup.select('.ipc-metadata-list__item > .ipc-metadata-list-item__label'):
             text = utils.html.as_text(tag)
             if 'original' in text:
                 return utils.html.as_text(tag.next_sibling)
